<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>InsertScriptItem</name>
    <message>
        <source>Position</source>
        <translation type="vanished">Pozice</translation>
    </message>
    <message>
        <location filename="../InsertScriptItemInit.js" line="+2"/>
        <source>Insert &amp;Script</source>
        <translation>Vložit &amp;skript</translation>
    </message>
</context>
</TS>
